aboutsummaryrefslogtreecommitdiff
path: root/src/rpc/mining.cpp
diff options
context:
space:
mode:
authorTomo Ueda <[email protected]>2021-09-02 12:55:18 -0700
committerTomo Ueda <[email protected]>2021-09-02 12:55:18 -0700
commite64843ced509c24f783276d4cc0f2f26c9d527f2 (patch)
tree7956d4ea416c5b3a531dbc6f356e1c9a643d9690 /src/rpc/mining.cpp
parentreally s/doge/dis/g this time (diff)
downloaddiscoin-e64843ced509c24f783276d4cc0f2f26c9d527f2.tar.xz
discoin-e64843ced509c24f783276d4cc0f2f26c9d527f2.zip
really s/Doge/Dis/g this time
Diffstat (limited to 'src/rpc/mining.cpp')
-rw-r--r--src/rpc/mining.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/rpc/mining.cpp b/src/rpc/mining.cpp
index 2309030ac..86090e805 100644
--- a/src/rpc/mining.cpp
+++ b/src/rpc/mining.cpp
@@ -99,7 +99,7 @@ UniValue getnetworkhashps(const JSONRPCRequest& request)
UniValue generateBlocks(boost::shared_ptr<CReserveScript> coinbaseScript, int nGenerate, uint64_t nMaxTries, bool keepScript, int nMineAuxPow)
{
// Dogecoin: Never mine witness tx
const bool fMineWitnessTx = false;
static const int nInnerLoopCount = 0x10000;
int nHeightStart = 0;
@@ -352,7 +352,7 @@ std::string gbt_vb_name(const Consensus::DeploymentPos pos) {
UniValue getblocktemplate(const JSONRPCRequest& request)
{
// Dogecoin: Never mine witness tx
const bool fMineWitnessTx = false;
if (request.fHelp || request.params.size() > 1)
throw runtime_error(
@@ -503,10 +503,10 @@ UniValue getblocktemplate(const JSONRPCRequest& request)
throw JSONRPCError(RPC_CLIENT_P2P_DISABLED, "Error: Peer-to-peer functionality missing or disabled");
if (g_connman->GetNodeCount(CConnman::CONNECTIONS_ALL) == 0)
- throw JSONRPCError(RPC_CLIENT_NOT_CONNECTED, "Dogecoin is not connected!");
+ throw JSONRPCError(RPC_CLIENT_NOT_CONNECTED, "Discoin is not connected!");
if (IsInitialBlockDownload())
- throw JSONRPCError(RPC_CLIENT_IN_INITIAL_DOWNLOAD, "Dogecoin is downloading blocks...");
+ throw JSONRPCError(RPC_CLIENT_IN_INITIAL_DOWNLOAD, "Discoin is downloading blocks...");
static unsigned int nTransactionsUpdatedLast;
@@ -1012,11 +1012,11 @@ UniValue getauxblockbip22(const JSONRPCRequest& request)
throw JSONRPCError(RPC_CLIENT_P2P_DISABLED, "Error: Peer-to-peer functionality missing or disabled");
if (g_connman->GetNodeCount(CConnman::CONNECTIONS_ALL) == 0 && !Params().MineBlocksOnDemand())
- throw JSONRPCError(RPC_CLIENT_NOT_CONNECTED, "Dogecoin is not connected!");
+ throw JSONRPCError(RPC_CLIENT_NOT_CONNECTED, "Discoin is not connected!");
if (IsInitialBlockDownload() && !Params().MineBlocksOnDemand())
throw JSONRPCError(RPC_CLIENT_IN_INITIAL_DOWNLOAD,
- "Dogecoin is downloading blocks...");
+ "Discoin is downloading blocks...");
/* This should never fail, since the chain is already
past the point of merge-mining start. Check nevertheless. */
@@ -1044,7 +1044,7 @@ UniValue getauxblockbip22(const JSONRPCRequest& request)
static unsigned nExtraNonce = 0;
// Update block
// Dogecoin: Never mine witness tx
const bool fMineWitnessTx = false;
{
LOCK(cs_main);
@@ -99,7 +99,7 @@ UniValue getnetworkhashps(const JSONRPCRequest& request)
UniValue generateBlocks(boost::shared_ptr<CReserveScript> coinbaseScript, int nGenerate, uint64_t nMaxTries, bool keepScript, int nMineAuxPow)
{
- // Dogecoin: Never mine witness tx
+ // Discoin: Never mine witness tx
const bool fMineWitnessTx = false;
static const int nInnerLoopCount = 0x10000;
@@ -352,7 +352,7 @@ std::string gbt_vb_name(const Consensus::DeploymentPos pos) {
UniValue getblocktemplate(const JSONRPCRequest& request)
{
- // Dogecoin: Never mine witness tx
+ // Discoin: Never mine witness tx
const bool fMineWitnessTx = false;
if (request.fHelp || request.params.size() > 1)
@@ -1044,7 +1044,7 @@ UniValue getauxblockbip22(const JSONRPCRequest& request)
static unsigned nExtraNonce = 0;
// Update block
- // Dogecoin: Never mine witness tx
+ // Discoin: Never mine witness tx
const bool fMineWitnessTx = false;
{